package com.xmlglobal.ebxml.iic;

import org.oasis.ebxmliic.ms.*;
import java.util.*;
import java.io.*;
import org.jdom.*;
import org.jdom.output.*;

public class SemanticRequirementImpl
    implements SemanticRequirement
{

    private List mAsserts = new ArrayList();
    private List mConditions = new ArrayList();
    private String mId;
    private String mSpecRef;
    private String mName;
    private String mRequirementType;

    public Assertion createAssertion()
    {
        return new AssertionImpl();
    }
    
    public void addAssertion(Assertion s)
    {
        mAsserts.add(s);   
    }
    
    public void removeAssertion(Assertion sr)
    {
        mAsserts.remove(mAsserts.indexOf(sr));
    }
    public Assertion getAssertion(int idx)
    {
        if (idx > mAsserts.size()) return null;
        return (Assertion)mAsserts.get(idx);
    }
    public int countAssertions()
    {
        return mAsserts.size();
    }
    public List getAllAssertions()
    {
        return mAsserts;
    }
    public void removeAllAssertions()
    {
        mAsserts.clear();
    }
    
    
    
    public Condition createCondition()
    {
        return new ConditionImpl();
    }
    
    public void addCondition(Condition s)
    {
        mConditions.add(s);   
    }
    
    public void removeCondition(Condition sr)
    {
        mConditions.remove(mConditions.indexOf(sr));
    }
    public Condition getCondition(int idx)
    {
        if (idx > mConditions.size()) return null;
        return (Condition)mConditions.get(idx);
    }
    public int countConditions()
    {
        return mConditions.size();
    }
    public List getAllConditions()
    {
        return mConditions;
    }
    public void removeAllConditions()
    {
        mConditions.clear();
    }
    
    
    
    public void setId(String id)
    {
	if (id == null) id = "";
        this.mId = id;
    }
    public String getId()
    {
        return this.mId;
    }
    
    public void setSpecRef(String sr)
    {
	if (sr == null) sr = "";
        this.mSpecRef = sr;
    }
    
    public String getSpecRef()
    {
        return this.mSpecRef;
    }
    public void setName(String name)
    {
	if (name == null) name = "";
        this.mName = name;
    }
    
    public String getName()
    {
        return this.mName;
    }
    
    public void setRequirementType(String ft)
    {
	if (ft == null) ft = "";
        this.mRequirementType = ft;
    }
    
    public String getRequirementType()
    {
        return this.mRequirementType;
    }
    
    public void createFromElement(Element e)
    {
        List trs = e.getChildren();
        for (int i = 0; i < trs.size(); i++)
        {
            Element ee = (Element)trs.get(i);
            if (ee.getName().equals("Condition"))
            {
                Condition tr = createCondition();
                tr.createFromElement(ee);
                addCondition(tr);
            }
            else if (ee.getName().equals("Assertion"))
            {
                Assertion tr = createAssertion();
                tr.createFromElement(ee);
                addAssertion(tr);   
            }
        }   
        setId(e.getAttributeValue("id"));
        setName(e.getAttributeValue("name"));
        setRequirementType(e.getAttributeValue("requirementType"));
        setSpecRef(e.getAttributeValue("specRef"));
    }    
    
    public Element serialize()
    {
        Element r = new Element("SemanticRequirement");
        r.setAttribute("id", mId);
        r.setAttribute("specRef", mSpecRef);
        r.setAttribute("requirementType", mRequirementType);
        r.setAttribute("name", mName);
        
        for (int i = 0; i < mAsserts.size(); i++)
        {
            Assertion tr = (Assertion)mAsserts.get(i);
            r.addContent(tr.serialize());
        }
        for (int i = 0; i < mConditions.size(); i++)
        {
            Condition tr = (Condition)mConditions.get(i);
            r.addContent(tr.serialize());
        }
        return r;
    }
    
}
